@@ -20,7 +20,7 @@ from magnetodb.storage.models import IndexDefinition
 from magnetodb.common.exception import MagnetoError
 
 
-#init decimal context to meet DynamoDB number type behaviour expectation
+# init decimal context to meet DynamoDB number type behaviour expectation
 DECIMAL_CONTEXT = decimal.Context(
     prec=38, rounding=None,
     traps=[],
@@ -473,7 +473,9 @@ class Parser():
                 )
                 range_key_attr_name = dynamodb_key_attr_name
 
-        return (hash_key_attr_name, range_key_attr_name)
+        if range_key_attr_name:
+            return hash_key_attr_name, range_key_attr_name
+        return hash_key_attr_name,
 
     @classmethod
     def format_key_schema(cls, key_attr_names):
@@ -673,24 +675,24 @@ class Parser():
                 (dynamodb_attr_type, dynamodb_attr_value) = (
                     dynamodb_condition_value.items()[0]
                 )
-                expected_attribute_conditions[attr_name] = (
+                expected_attribute_conditions[attr_name] = [
                     models.ExpectedCondition.eq(
                         cls.decode_attr_value(
                             dynamodb_attr_type, dynamodb_attr_value
                         )
                     )
-                )
+                ]
 
             elif Props.EXISTS in dynamodb_condition:
                 dynamodb_condition_value = dynamodb_condition[Props.EXISTS]
 
                 assert isinstance(dynamodb_condition_value, bool)
 
-                expected_attribute_conditions[attr_name] = (
+                expected_attribute_conditions[attr_name] = [
                     models.ExpectedCondition.exists()
                     if dynamodb_condition_value else
                     models.ExpectedCondition.not_exists()
-                )
+                ]
 
         return expected_attribute_conditions
 
