@@ -17,13 +17,27 @@ import json
 import unittest
 import uuid
 import binascii
+from magnetodb.common import exception
 
-from magnetodb.common.cassandra import cluster
+from cassandra import cluster
 from cassandra import query
-
+from magnetodb.common.cassandra.cluster_handler import ClusterHandler
 from magnetodb.storage import models
-from magnetodb.storage.impl import cassandra_impl as impl
-
+from magnetodb.storage.driver.cassandra import (
+    cassandra_impl,
+    SYSTEM_COLUMN_INDEX_NAME,
+    SYSTEM_COLUMN_INDEX_VALUE_STRING,
+    SYSTEM_COLUMN_INDEX_VALUE_NUMBER,
+    SYSTEM_COLUMN_INDEX_VALUE_BLOB,
+    USER_PREFIX,
+    SYSTEM_COLUMN_EXTRA_ATTR_DATA,
+    SYSTEM_COLUMN_EXTRA_ATTR_TYPES,
+    SYSTEM_COLUMN_ATTR_EXIST
+)
+from magnetodb.storage.manager.simple_impl import SimpleStorageManager
+from magnetodb.storage.table_info_repo.cassandra_impl import (
+    CassandraTableInfoRepository
+)
 
 TEST_CONNECTION = {
     'contact_points': ("localhost",),
@@ -95,9 +109,9 @@ class TestCassandraBase(unittest.TestCase):
     }
 
     test_data_system_fields = {
-        impl.SYSTEM_COLUMN_EXTRA_ATTR_DATA: 'map<text,blob>',
-        impl.SYSTEM_COLUMN_EXTRA_ATTR_TYPES: 'map<text,text>',
-        impl.SYSTEM_COLUMN_ATTR_EXIST: 'set<text>'
+        SYSTEM_COLUMN_EXTRA_ATTR_DATA: 'map<text,blob>',
+        SYSTEM_COLUMN_EXTRA_ATTR_TYPES: 'map<text,text>',
+        SYSTEM_COLUMN_ATTR_EXIST: 'set<text>'
     }
 
     test_data_dynamic_fields = {
@@ -118,16 +132,21 @@ class TestCassandraBase(unittest.TestCase):
         )
     }
 
-    C2S_TYPES = impl.CASSANDRA_TO_STORAGE_TYPES
+    C2S_TYPES = cassandra_impl.CASSANDRA_TO_STORAGE_TYPES
 
     @classmethod
     def setUpClass(cls):
         super(TestCassandraBase, cls).setUpClass()
 
-        cls.CASANDRA_STORAGE_IMPL = impl.CassandraStorageImpl(
-            query_timeout=300, **TEST_CONNECTION)
-
         cls.CLUSTER = cluster.Cluster(**TEST_CONNECTION)
+        cluster_hadler = ClusterHandler(cls.CLUSTER, query_timeout=300)
+        table_info_repo = CassandraTableInfoRepository(cluster_hadler)
+        storage_driver = cassandra_impl.CassandraStorageDriver(
+            cluster_hadler, table_info_repo
+        )
+        cls.CASANDRA_STORAGE_IMPL = SimpleStorageManager(storage_driver,
+                                                         table_info_repo)
+
         cls.SESSION = cls.CLUSTER.connect()
         cls.SESSION.row_factory = query.dict_factory
         cls.SESSION.default_timeout = 300
@@ -171,14 +190,14 @@ class TestCassandraBase(unittest.TestCase):
     @classmethod
     def _create_tenant(cls, tenant):
         query = "CREATE KEYSPACE {}{} WITH replication".format(
-            impl.USER_PREFIX, tenant)
+            USER_PREFIX, tenant)
         query += " = {'class':'SimpleStrategy', 'replication_factor':1}"
 
         cls.SESSION.execute(query)
 
     @classmethod
     def _drop_tenant(cls, tenant):
-        query = ("DROP KEYSPACE {}{}".format(impl.USER_PREFIX, tenant))
+        query = ("DROP KEYSPACE {}{}".format(USER_PREFIX, tenant))
 
         cls.SESSION.execute(query)
 
@@ -197,8 +216,8 @@ class TestCassandraBase(unittest.TestCase):
         tenant = tenant or self.tenant
         table_name = table_name or self.table_name
 
-        internal_table_name = impl.USER_PREFIX + self._get_unique_name()
-        keyspace = impl.USER_PREFIX + tenant
+        internal_table_name = USER_PREFIX + self._get_unique_name()
+        keyspace = USER_PREFIX + tenant
 
         query = (
             "INSERT INTO magnetodb.table_info (tenant, name, exists, "
@@ -217,11 +236,11 @@ class TestCassandraBase(unittest.TestCase):
 
         for name, field in self.test_data_keys.iteritems():
             typ, _, _ = field
-            query += '{}{} {},'.format(impl.USER_PREFIX, name, typ)
+            query += '{}{} {},'.format(USER_PREFIX, name, typ)
 
         for name, field in self.test_data_predefined_fields.iteritems():
             typ, _, _ = field
-            query += '{}{} {},'.format(impl.USER_PREFIX, name, typ)
+            query += '{}{} {},'.format(USER_PREFIX, name, typ)
 
         for name, field in self.test_data_system_fields.iteritems():
             query += '{} {},'.format(name, field)
@@ -230,21 +249,21 @@ class TestCassandraBase(unittest.TestCase):
             query += (
                 "{} text, {} text, {} decimal, {} blob,"
                 " PRIMARY KEY({}id, {}, {}, {}, {}, {}range))".format(
-                    impl.SYSTEM_COLUMN_INDEX_NAME,
-                    impl.SYSTEM_COLUMN_INDEX_VALUE_STRING,
-                    impl.SYSTEM_COLUMN_INDEX_VALUE_NUMBER,
-                    impl.SYSTEM_COLUMN_INDEX_VALUE_BLOB,
-                    impl.USER_PREFIX,
-                    impl.SYSTEM_COLUMN_INDEX_NAME,
-                    impl.SYSTEM_COLUMN_INDEX_VALUE_STRING,
-                    impl.SYSTEM_COLUMN_INDEX_VALUE_NUMBER,
-                    impl.SYSTEM_COLUMN_INDEX_VALUE_BLOB,
-                    impl.USER_PREFIX
+                    SYSTEM_COLUMN_INDEX_NAME,
+                    SYSTEM_COLUMN_INDEX_VALUE_STRING,
+                    SYSTEM_COLUMN_INDEX_VALUE_NUMBER,
+                    SYSTEM_COLUMN_INDEX_VALUE_BLOB,
+                    USER_PREFIX,
+                    SYSTEM_COLUMN_INDEX_NAME,
+                    SYSTEM_COLUMN_INDEX_VALUE_STRING,
+                    SYSTEM_COLUMN_INDEX_VALUE_NUMBER,
+                    SYSTEM_COLUMN_INDEX_VALUE_BLOB,
+                    USER_PREFIX
                 )
             )
         else:
             query += " PRIMARY KEY({}id, {}range))".format(
-                impl.USER_PREFIX, impl.USER_PREFIX
+                USER_PREFIX, USER_PREFIX
             )
         self.SESSION.execute(query)
 
@@ -258,7 +277,7 @@ class TestCassandraBase(unittest.TestCase):
         result = self.SESSION.execute(query)
         internal_table_name = result[0]["internal_name"]
         query = "DROP TABLE IF EXISTS {}{}.{}".format(
-            impl.USER_PREFIX, tenant, internal_table_name
+            USER_PREFIX, tenant, internal_table_name
         )
         self.SESSION.execute(query)
         query = (
@@ -283,12 +302,12 @@ class TestCassandraBase(unittest.TestCase):
         schema = models.ModelBase.from_json(result[0]["schema"])
 
         query = "SELECT * FROM {}{}.{}".format(
-            impl.USER_PREFIX, tenant, internal_table_name)
+            USER_PREFIX, tenant, internal_table_name)
 
         if schema.index_def_map:
             query += " WHERE {}={}".format(
-                impl.SYSTEM_COLUMN_INDEX_NAME,
-                impl.ENCODED_DEFAULT_STRING_VALUE
+                SYSTEM_COLUMN_INDEX_NAME,
+                cassandra_impl.ENCODED_DEFAULT_STRING_VALUE
             )
 
         query += " ALLOW FILTERING"
@@ -309,7 +328,7 @@ class TestCassandraBase(unittest.TestCase):
         schema = models.ModelBase.from_json(result[0]["schema"])
 
         query = "UPDATE {}{}.{} SET ".format(
-            impl.USER_PREFIX, self.tenant, internal_table_name)
+            USER_PREFIX, self.tenant, internal_table_name)
 
         predefined_fields = (
             predefined_fields or self.test_data_predefined_fields
@@ -320,14 +339,14 @@ class TestCassandraBase(unittest.TestCase):
         set_items = []
         for name, field in predefined_fields.iteritems():
             _, sval, _ = field
-            set_items.append('{}{}={}'.format(impl.USER_PREFIX, name, sval))
+            set_items.append('{}{}={}'.format(USER_PREFIX, name, sval))
 
         for name, field in dynamic_fields.iteritems():
             typ, sval, _ = field
             set_items.append("{}['{}'] = 0x{}".format(
-                impl.SYSTEM_COLUMN_EXTRA_ATTR_DATA, name, sval))
+                SYSTEM_COLUMN_EXTRA_ATTR_DATA, name, sval))
             set_items.append("{}['{}'] ='{}'".format(
-                impl.SYSTEM_COLUMN_EXTRA_ATTR_TYPES, name, typ))
+                SYSTEM_COLUMN_EXTRA_ATTR_TYPES, name, typ))
 
         for name, field in dict(self.test_data_keys.items() +
                                 predefined_fields.items() +
@@ -335,25 +354,25 @@ class TestCassandraBase(unittest.TestCase):
             typ, sval, _ = field
 
             set_items.append("{} = {} + {{'{}'}}".format(
-                impl.SYSTEM_COLUMN_ATTR_EXIST, impl.SYSTEM_COLUMN_ATTR_EXIST,
+                SYSTEM_COLUMN_ATTR_EXIST, SYSTEM_COLUMN_ATTR_EXIST,
                 name,
             ))
 
         query += ",".join(set_items)
 
         query += " WHERE {}id = {} AND {}range='{}'".format(
-            impl.USER_PREFIX, id_value, impl.USER_PREFIX, range_value)
+            USER_PREFIX, id_value, USER_PREFIX, range_value)
 
         if schema.index_def_map:
             default_index_cond_params = (
-                impl.SYSTEM_COLUMN_INDEX_NAME,
-                impl.ENCODED_DEFAULT_STRING_VALUE,
-                impl.SYSTEM_COLUMN_INDEX_VALUE_BLOB,
-                impl.ENCODED_DEFAULT_BLOB_VALUE,
-                impl.SYSTEM_COLUMN_INDEX_VALUE_STRING,
-                impl.ENCODED_DEFAULT_STRING_VALUE,
-                impl.SYSTEM_COLUMN_INDEX_VALUE_NUMBER,
-                impl.ENCODED_DEFAULT_NUMBER_VALUE
+                SYSTEM_COLUMN_INDEX_NAME,
+                cassandra_impl.ENCODED_DEFAULT_STRING_VALUE,
+                SYSTEM_COLUMN_INDEX_VALUE_BLOB,
+                cassandra_impl.ENCODED_DEFAULT_BLOB_VALUE,
+                SYSTEM_COLUMN_INDEX_VALUE_STRING,
+                cassandra_impl.ENCODED_DEFAULT_STRING_VALUE,
+                SYSTEM_COLUMN_INDEX_VALUE_NUMBER,
+                cassandra_impl.ENCODED_DEFAULT_NUMBER_VALUE
             )
 
             queries = [
@@ -550,10 +569,9 @@ class TestCassandraDeleteItem(TestCassandraBase):
             {'id': models.AttributeValue.number(1),
              'range': models.AttributeValue.str('1')})
 
-        result = self.CASANDRA_STORAGE_IMPL.delete_item(
-            self.context, del_req, expected)
-
-        self.assertFalse(result)
+        self.assertRaises(exception.ConditionalCheckFailedException,
+                          self.CASANDRA_STORAGE_IMPL.delete_item,
+                          self.context, del_req, expected)
 
         all = self._select_all()
 
@@ -606,10 +624,9 @@ class TestCassandraDeleteItem(TestCassandraBase):
             {'id': models.AttributeValue.number(1),
              'range': models.AttributeValue.str('1')})
 
-        result = self.CASANDRA_STORAGE_IMPL.delete_item(
-            self.context, del_req, expected)
-
-        self.assertFalse(result)
+        self.assertRaises(exception.ConditionalCheckFailedException,
+                          self.CASANDRA_STORAGE_IMPL.delete_item,
+                          self.context, del_req, expected)
 
         all = self._select_all()
 
@@ -1151,7 +1168,7 @@ class TestCassandraUpdateItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, keys_condition)
 
-        self.assertEquals([expected], result.items)
+        self.assertEqual([expected], result.items)
 
     def test_update_item_put_number(self):
         self._create_table(indexed=True)
@@ -1184,7 +1201,7 @@ class TestCassandraUpdateItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, keys_condition)
 
-        self.assertEquals([expected], result.items)
+        self.assertEqual([expected], result.items)
 
     def test_update_item_put_blob(self):
         self._create_table(indexed=True)
@@ -1217,7 +1234,7 @@ class TestCassandraUpdateItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, keys_condition)
 
-        self.assertEquals([expected], result.items)
+        self.assertEqual([expected], result.items)
 
     def test_update_item_put_set_str(self):
         self._create_table(indexed=True)
@@ -1251,7 +1268,7 @@ class TestCassandraUpdateItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, keys_condition)
 
-        self.assertEquals([expected], result.items)
+        self.assertEqual([expected], result.items)
 
     def test_update_item_put_set_number(self):
         self._create_table(indexed=True)
@@ -1284,7 +1301,7 @@ class TestCassandraUpdateItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, keys_condition)
 
-        self.assertEquals([expected], result.items)
+        self.assertEqual([expected], result.items)
 
     def test_update_item_put_set_blob(self):
         self._create_table(indexed=True)
@@ -1318,7 +1335,7 @@ class TestCassandraUpdateItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, keys_condition)
 
-        self.assertEquals([expected], result.items)
+        self.assertEqual([expected], result.items)
 
     def test_update_item_put_dynamic_str(self):
         self._create_table(indexed=True)
@@ -1351,7 +1368,7 @@ class TestCassandraUpdateItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, keys_condition)
 
-        self.assertEquals([expected], result.items)
+        self.assertEqual([expected], result.items)
 
     def test_update_item_put_dynamic_number(self):
         self._create_table(indexed=True)
@@ -1384,7 +1401,7 @@ class TestCassandraUpdateItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, keys_condition)
 
-        self.assertEquals([expected], result.items)
+        self.assertEqual([expected], result.items)
 
     def test_update_item_put_dynamic_blob(self):
         self._create_table(indexed=True)
@@ -1417,7 +1434,7 @@ class TestCassandraUpdateItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, keys_condition)
 
-        self.assertEquals([expected], result.items)
+        self.assertEqual([expected], result.items)
 
     def test_update_item_put_dynamic_set_str(self):
         self._create_table(indexed=True)
@@ -1451,7 +1468,7 @@ class TestCassandraUpdateItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, keys_condition)
 
-        self.assertEquals([expected], result.items)
+        self.assertEqual([expected], result.items)
 
     def test_update_item_put_dynamic_set_number(self):
         self._create_table(indexed=True)
@@ -1485,7 +1502,7 @@ class TestCassandraUpdateItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, keys_condition)
 
-        self.assertEquals([expected], result.items)
+        self.assertEqual([expected], result.items)
 
     def test_update_item_put_dynamic_set_blob(self):
         self._create_table(indexed=True)
@@ -1519,7 +1536,7 @@ class TestCassandraUpdateItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, keys_condition)
 
-        self.assertEquals([expected], result.items)
+        self.assertEqual([expected], result.items)
 
     def test_update_item_delete(self):
         self._create_table(indexed=True)
@@ -1553,7 +1570,7 @@ class TestCassandraUpdateItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, keys_condition)
 
-        self.assertEquals([expected], result.items)
+        self.assertEqual([expected], result.items)
 
 
 class TestCassandraPutItem(TestCassandraBase):
@@ -1578,7 +1595,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_number(self):
         self._create_table(indexed=True)
@@ -1601,7 +1618,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_blob(self):
         self._create_table(indexed=True)
@@ -1624,7 +1641,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_set_str(self):
         self._create_table(indexed=True)
@@ -1648,7 +1665,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_set_number(self):
         self._create_table(indexed=True)
@@ -1672,7 +1689,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_set_blob(self):
         self._create_table(indexed=True)
@@ -1696,7 +1713,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_dynamic_str(self):
         self._create_table(indexed=True)
@@ -1719,7 +1736,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_dynamic_number(self):
         self._create_table(indexed=True)
@@ -1742,7 +1759,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_dynamic_blob(self):
         self._create_table(indexed=True)
@@ -1765,7 +1782,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_dynamic_set_str(self):
         self._create_table(indexed=True)
@@ -1789,7 +1806,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_dynamic_set_number(self):
         self._create_table(indexed=True)
@@ -1813,7 +1830,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_dynamic_set_blob(self):
         self._create_table(indexed=True)
@@ -1837,7 +1854,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_expected_str(self):
         self._create_table(indexed=True)
@@ -1870,7 +1887,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_expected_number(self):
         self._create_table(indexed=True)
@@ -1903,7 +1920,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_expected_blob(self):
         self._create_table(indexed=True)
@@ -1940,7 +1957,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_expected_set_str(self):
         self._create_table(indexed=True)
@@ -1975,7 +1992,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_expected_set_number(self):
         self._create_table(indexed=True)
@@ -2010,7 +2027,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
     def test_put_item_expected_set_blob(self):
         self._create_table(indexed=True)
@@ -2049,10 +2066,8 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
-    @unittest.skip("Skipped due to Cassandra 2.0.6 bug"
-                   "(https://issues.apache.org/jira/browse/CASSANDRA-6914)")
     def test_put_item_expected_dynamic_str(self):
         self._create_table(indexed=True)
         self._insert_data()
@@ -2084,10 +2099,8 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
-    @unittest.skip("Skipped due to Cassandra 2.0.6 bug"
-                   "(https://issues.apache.org/jira/browse/CASSANDRA-6914)")
     def test_put_item_expected_dynamic_number(self):
         self._create_table(indexed=True)
         self._insert_data()
@@ -2123,10 +2136,8 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
-    @unittest.skip("Skipped due to Cassandra 2.0.6 bug"
-                   "(https://issues.apache.org/jira/browse/CASSANDRA-6914)")
     def test_put_item_expected_dynamic_blob(self):
         self._create_table(indexed=True)
         self._insert_data()
@@ -2159,10 +2170,8 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
-    @unittest.skip("Skipped due to Cassandra 2.0.6 bug"
-                   "(https://issues.apache.org/jira/browse/CASSANDRA-6914)")
     def test_put_item_expected_dynamic_set_str(self):
         self._create_table(indexed=True)
         self._insert_data()
@@ -2196,10 +2205,8 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
-    @unittest.skip("Skipped due to Cassandra 2.0.6 bug"
-                   "(https://issues.apache.org/jira/browse/CASSANDRA-6914)")
     def test_put_item_expected_dynamic_set_number(self):
         self._create_table(indexed=True)
         self._insert_data()
@@ -2233,10 +2240,8 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
-    @unittest.skip("Skipped due to Cassandra 2.0.6 bug"
-                   "(https://issues.apache.org/jira/browse/CASSANDRA-6914)")
     def test_put_item_expected_dynamic_set_blob(self):
         self._create_table(indexed=True)
         self._insert_data()
@@ -2270,7 +2275,7 @@ class TestCassandraPutItem(TestCassandraBase):
         result = self.CASANDRA_STORAGE_IMPL.select_item(
             self.context, self.table_name, key_condition)
 
-        self.assertEquals([put], result.items)
+        self.assertEqual([put], result.items)
 
 
 class TestCassandraScan(TestCassandraBase):
@@ -2507,4 +2512,4 @@ class TestCassandraBatch(TestCassandraBase):
             result = self.CASANDRA_STORAGE_IMPL.select_item(
                 self.context, self.table_name, key)
 
-            self.assertEquals([item], result.items)
+            self.assertEqual([item], result.items)
