@@ -14,6 +14,7 @@
 #    under the License.
 import random
 import string
+import binascii
 
 from tempest.test import attr
 from tempest.api.keyvalue.rest_base.base import MagnetoDBTestCase
@@ -31,12 +32,14 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
         return ''.join(random.choice(string.lowercase + string.digits)
                        for i in range(length))
 
+    @attr(type='PI-3')
     def test_put_item_update_one_attribute(self):
         self.table_name = rand_name().replace('-', '')
-        self.client.create_table(
+        self._create_test_table(
             [{'attribute_name': 'message', 'attribute_type': 'S'}],
             self.table_name,
-            [{'attribute_name': 'message', 'key_type': 'HASH'}])
+            [{'attribute_name': 'message', 'key_type': 'HASH'}],
+            wait_for_active=True)
         item = {
             "message": {"S": 'message_text'},
             "author": {"S": "Bob"},
@@ -62,12 +65,14 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
         self.assertEqual(get_resp[1]['item']['author'],
                          {'S': 'Alice'})
 
+    @attr(type='PI-4')
     def test_put_item_update_few_attributes(self):
         self.table_name = rand_name().replace('-', '')
-        self.client.create_table(
+        self._create_test_table(
             [{'attribute_name': 'message', 'attribute_type': 'S'}],
             self.table_name,
-            [{'attribute_name': 'message', 'key_type': 'HASH'}])
+            [{'attribute_name': 'message', 'key_type': 'HASH'}],
+            wait_for_active=True)
         item = {
             "message": {"S": 'message_text'},
             "author": {"S": "Bob"},
@@ -97,12 +102,14 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
         self.assertEqual(get_resp[1]['item']['id'],
                          {'N': '2'})
 
+    @attr(type='PI-5')
     def test_put_item_update_few_lines_without_exist_state(self):
         self.table_name = rand_name().replace('-', '')
-        self.client.create_table(
+        self._create_test_table(
             [{'attribute_name': 'message', 'attribute_type': 'S'}],
             self.table_name,
-            [{'attribute_name': 'message', 'key_type': 'HASH'}])
+            [{'attribute_name': 'message', 'key_type': 'HASH'}],
+            wait_for_active=True)
         item = {
             "message": {"S": 'message_text'},
             "author": {"S": "Bob"},
@@ -131,16 +138,19 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
         self.assertEqual(get_resp[1]['item']['id'],
                          {'N': '2'})
 
+    @attr(type='PI-10')
     def test_put_item_with_few_attributes_of_type_b(self):
         self.table_name = rand_name().replace('-', '')
-        self.client.create_table(
+        self._create_test_table(
             [{"attribute_name": "message", "attribute_type": "S"}],
             self.table_name,
-            [{'attribute_name': 'message', 'key_type': 'HASH'}])
+            [{'attribute_name': 'message', 'key_type': 'HASH'}],
+            wait_for_active=True)
+        blob = binascii.hexlify('fblob')
         item = {
             "message": {"B": "qazw"},
             "author": {"B": "qwer"},
-            "blob": {"B": "tyui"}
+            "blob": {"B": blob}
         }
         put_resp = self.client.put_item(self.table_name, item)
         self.assertEqual(put_resp[1], {})
@@ -149,14 +159,16 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
                                         consistent_read=True)
         self.assertEqual(get_resp[1]["item"]["message"], {"B": "qazw"})
         self.assertEqual(get_resp[1]["item"]["author"], {"B": "qwer"})
-        self.assertEqual(get_resp[1]['item']["blob"], {"B": "tyui"})
+        self.assertEqual(get_resp[1]['item']["blob"], {"B": blob})
 
+    @attr(type='PI-11')
     def test_put_item_with_few_attributes_of_type_bs(self):
         self.table_name = rand_name().replace('-', '')
-        self.client.create_table(
+        self._create_test_table(
             [{"attribute_name": "message", "attribute_type": "S"}],
             self.table_name,
-            [{'attribute_name': 'message', 'key_type': 'HASH'}])
+            [{'attribute_name': 'message', 'key_type': 'HASH'}],
+            wait_for_active=True)
         item = {
             "message": {"S": "message"},
             "author": {"BS": ["qqqq", "wwww"]},
@@ -172,12 +184,14 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
         self.assertEqual(set(get_resp[1]['item']["blob"]["BS"]),
                          {"rrrr", "tttt"})
 
+    @attr(type='PI-15')
     def test_put_item_with_attributes_of_all_types(self):
         self.table_name = rand_name().replace('-', '')
-        self.client.create_table(
+        self._create_test_table(
             [{"attribute_name": "message", "attribute_type": "S"}],
             self.table_name,
-            [{'attribute_name': 'message', 'key_type': 'HASH'}])
+            [{'attribute_name': 'message', 'key_type': 'HASH'}],
+            wait_for_active=True)
         item = {
             "message": {"S": "message"},
             "author": {"SS": ["eeee", "qqqq", "nnnn"]},
@@ -200,12 +214,122 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
         self.assertEqual(set(get_resp[1]['item']["blobs"]["BS"]),
                          {"qqqq", "eeee", "wwww"})
 
-    def test_put_item_with_returned_all_old(self):
+    @attr(type='PI-50')
+    def test_put_item_exist_state_by_default(self):
         self.table_name = rand_name().replace('-', '')
-        self.client.create_table(
+        self._create_test_table(
             [{'attribute_name': 'message', 'attribute_type': 'S'}],
             self.table_name,
-            [{'attribute_name': 'message', 'key_type': 'HASH'}])
+            [{'attribute_name': 'message', 'key_type': 'HASH'}],
+            wait_for_active=True)
+        item = {
+            "message": {"S": 'message_text'},
+            "author": {"S": "Bob"},
+            "id": {"N": "1"}
+        }
+        new_item = {
+            "message": {"S": "message_text"},
+            "author": {"S": "Alice"},
+            "id": {"N": "2"}
+        }
+        expected = {
+            "author": {
+                "value": {"S": "Bob"}
+            }
+        }
+        put_resp = self.client.put_item(self.table_name, item)
+        self.assertEqual(put_resp[1], {})
+        put_resp = self.client.put_item(self.table_name,
+                                        new_item, expected)
+        self.assertEqual(put_resp[1], {})
+        get_resp = self.client.get_item(self.table_name,
+                                        {"message": {"S": 'message_text'}},
+                                        consistent_read=True)
+        self.assertEqual(get_resp[1]['item']['author'],
+                         {'S': 'Alice'})
+        self.assertEqual(get_resp[1]['item']['id'],
+                         {'N': '2'})
+
+    @attr(type='PI-51')
+    def test_put_item_exists_true(self):
+        self.table_name = rand_name().replace('-', '')
+        self._create_test_table(
+            [{'attribute_name': 'message', 'attribute_type': 'S'}],
+            self.table_name,
+            [{'attribute_name': 'message', 'key_type': 'HASH'}],
+            wait_for_active=True)
+        item = {
+            "message": {"S": 'message_text'},
+            "author": {"S": "Bob"},
+            "id": {"N": "1"}
+        }
+        new_item = {
+            "message": {"S": "message_text"},
+            "author": {"S": "Alice"},
+            "id": {"N": "2"}
+        }
+        expected = {
+            "author": {
+                "exists": "true",
+                "value": {"S": "Bob"}
+            }
+        }
+        put_resp = self.client.put_item(self.table_name, item)
+        self.assertEqual(put_resp[1], {})
+        put_resp = self.client.put_item(self.table_name,
+                                        new_item, expected)
+        self.assertEqual(put_resp[1], {})
+        get_resp = self.client.get_item(self.table_name,
+                                        {"message": {"S": 'message_text'}},
+                                        consistent_read=True)
+        self.assertEqual(get_resp[1]['item']['author'],
+                         {'S': 'Alice'})
+        self.assertEqual(get_resp[1]['item']['id'],
+                         {'N': '2'})
+
+    @attr(type='PI-52')
+    def test_put_item_exists_false(self):
+        self.table_name = rand_name().replace('-', '')
+        self._create_test_table(
+            [{'attribute_name': 'message', 'attribute_type': 'S'}],
+            self.table_name,
+            [{'attribute_name': 'message', 'key_type': 'HASH'}],
+            wait_for_active=True)
+        item = {
+            "message": {"S": 'message_text'},
+            "author": {"S": "Bob"},
+        }
+        new_item = {
+            "message": {"S": "message_text"},
+            "author": {"S": "Alice"},
+            "id": {"N": "2"}
+        }
+        expected = {
+            "id": {
+                "exists": "false"
+            }
+        }
+        put_resp = self.client.put_item(self.table_name, item)
+        self.assertEqual(put_resp[1], {})
+        put_resp = self.client.put_item(self.table_name,
+                                        new_item, expected)
+        self.assertEqual(put_resp[1], {})
+        get_resp = self.client.get_item(self.table_name,
+                                        {"message": {"S": 'message_text'}},
+                                        consistent_read=True)
+        self.assertEqual(get_resp[1]['item']['author'],
+                         {'S': 'Alice'})
+        self.assertEqual(get_resp[1]['item']['id'],
+                         {'N': '2'})
+
+    @attr(type='PI-81')
+    def test_put_item_with_returned_all_old(self):
+        self.table_name = rand_name().replace('-', '')
+        self._create_test_table(
+            [{'attribute_name': 'message', 'attribute_type': 'S'}],
+            self.table_name,
+            [{'attribute_name': 'message', 'key_type': 'HASH'}],
+            wait_for_active=True)
         item = {
             "message": {"S": 'message_text'},
             "authors": {"SS": ["Alice", "Bob"]},
@@ -234,21 +358,23 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
         self.assertEqual(set(put_resp[1]["attributes"]["others"]["SS"]),
                          {"qqqq", "wwww"})
 
-    @attr(type='negative')
+    @attr(type=['PI-101', 'negative'])
     def test_put_item_in_nonexistent_table(self):
         item = {
             "message": {"S": 'message_text'},
             "author": {"S": "Bob"}
         }
         with self.assertRaises(exceptions.NotFound) as raises_cm:
-            self.client.put_item("nonexistent_table", item)
+            self.client.put_item("nonexistenttable", item)
 
         exception = raises_cm.exception
-        self.assertEqual(exception.body["message"],
-                         "Requested resource not found")
-        self.assertIn("ResourceNotFoundException", exception.body["__type"])
+        self.assertIn("Not Found", exception._error_string)
+        self.assertIn("The resource could not be found.",
+                      exception._error_string)
+        self.assertIn("Table 'nonexistenttable' does not exist",
+                      exception._error_string)
 
-    @attr(type='negative')
+    @attr(type=['PI-102', 'negative'])
     def test_put_item_in_table_with_wrong_name(self):
         item = {
             "message": {"S": 'message_text'},
@@ -267,7 +393,7 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
                          " greater than or equal to 3")
         self.assertIn("ValidationException", exception.body["__type"])
 
-    @attr(type='negative')
+    @attr(type=['PI-103', 'negative'])
     def test_put_item_in_table_with_short_name(self):
         item = {
             "message": {"S": 'message_text'},
@@ -283,7 +409,7 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
                          " Member must have length greater than or equal to 3")
         self.assertIn("ValidationException", exception.body["__type"])
 
-    @attr(type='negative')
+    @attr(type=['PI-104', 'negative'])
     def test_put_item_in_table_with_long_name(self):
         item = {
             "message": {"S": 'message_text'},
@@ -302,13 +428,14 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
                          " Member must have length less than or equal to 255")
         self.assertIn("ValidationException", exception.body["__type"])
 
-    @attr(type='negative')
+    @attr(type=['PI-120', 'negative'])
     def test_put_item_conditional_check_failed(self):
         self.table_name = rand_name().replace('-', '')
-        self.client.create_table(
+        self._create_test_table(
             [{'attribute_name': 'message', 'attribute_type': 'S'}],
             self.table_name,
-            [{'attribute_name': 'message', 'key_type': 'HASH'}])
+            [{'attribute_name': 'message', 'key_type': 'HASH'}],
+            wait_for_active=True)
         item = {
             "message": {"S": 'message_text'},
             "author": {"S": "Bob"},
@@ -333,13 +460,14 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
         self.assertIn("ConditionalCheckFailedException",
                       exception.body["__type"])
 
-    @attr(type='negative')
+    @attr(type=['PI-114', 'negative'])
     def test_put_item_wrong_expected_section(self):
         self.table_name = rand_name().replace('-', '')
-        self.client.create_table(
+        self._create_test_table(
             [{'attribute_name': 'message', 'attribute_type': 'S'}],
             self.table_name,
-            [{'attribute_name': 'message', 'key_type': 'HASH'}])
+            [{'attribute_name': 'message', 'key_type': 'HASH'}],
+            wait_for_active=True)
         item = {
             "message": {"S": 'message_text'},
             "author": {"S": "Bob"},
@@ -364,13 +492,14 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
         self.assertIn("ConditionalCheckFailedException",
                       exception.body["__type"])
 
-    @attr(type='negative')
+    @attr(type=['PI-111', 'negative'])
     def test_put_item_wrong_data_type_in_expected(self):
         self.table_name = rand_name().replace('-', '')
-        self.client.create_table(
+        self._create_test_table(
             [{'attribute_name': 'message', 'attribute_type': 'S'}],
             self.table_name,
-            [{'attribute_name': 'message', 'key_type': 'HASH'}])
+            [{'attribute_name': 'message', 'key_type': 'HASH'}],
+            wait_for_active=True)
         item = {
             "message": {"S": 'message_text'},
             "author": {"S": "Bob"},
@@ -396,16 +525,16 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
                          "supported datatypes")
         self.assertIn("ValidationException", exception.body["__type"])
 
-    @attr(type='negative')
+    @attr(type=['PI-113', 'negative'])
     def test_put_item_no_attribute_value(self):
         self.table_name = rand_name().replace('-', '')
-        self.client.create_table(
+        self._create_test_table(
             [{'attribute_name': 'message', 'attribute_type': 'S'}],
             self.table_name,
-            [{'attribute_name': 'message', 'key_type': 'HASH'}])
+            [{'attribute_name': 'message', 'key_type': 'HASH'}],
+            wait_for_active=True)
         item = {
-            "message": {"S": 'message_text'},
-            "author": {},
+            "message": {}
         }
         with self.assertRaises(exceptions.BadRequest) as raises_cm:
             self.client.put_item(self.table_name, item)
@@ -416,3 +545,19 @@ class MagnetoDBPutItemTest(MagnetoDBTestCase):
                          " must contain exactly one of the "
                          "supported datatypes")
         self.assertIn("ValidationException", exception.body["__type"])
+
+    @attr(type=['PI-123', 'negative'])
+    def test_put_item_resource_not_found_exception(self):
+        item = {
+            "message": {"S": 'message_text'},
+            "author": {"S": "Bob"}
+        }
+        with self.assertRaises(exceptions.NotFound) as raises_cm:
+            self.client.put_item("nonexistent_table", item)
+
+        exception = raises_cm.exception
+        self.assertIn("Not Found", exception._error_string)
+        self.assertIn("The resource could not be found.",
+                      exception._error_string)
+        self.assertIn("Table 'nonexistenttable' does not exists",
+                      exception._error_string)
