@@ -556,6 +556,26 @@ StressGroup = [
 ]
 
 
+cli_group = cfg.OptGroup(name='cli', title="cli Configuration Options")
+
+CLIGroup = [
+    cfg.BoolOpt('enabled',
+                default=True,
+                help="enable cli tests"),
+    cfg.StrOpt('cli_dir',
+               default='/usr/local/bin',
+               help="directory where python client binaries are located"),
+    cfg.BoolOpt('has_manage',
+                default=True,
+                help=("Whether the tempest run location has access to the "
+                      "*-manage commands. In a pure blackbox environment "
+                      "it will not.")),
+    cfg.IntOpt('timeout',
+               default=15,
+               help="Number of seconds to wait on a CLI timeout"),
+]
+
+
 scenario_group = cfg.OptGroup(name='scenario', title='Scenario Test Options')
 
 ScenarioGroup = [
@@ -627,12 +647,22 @@ DebugGroup = [
 ]
 
 
+magnetodb_group = cfg.OptGroup(name="magnetodb",
+                               title="Key-Value storage options")
+
+MagnetoDBGroup = [
+    cfg.StrOpt('service_type',
+               default="kv-storage",
+               help="The name of the MagnetoDB service type"),
+]
+
+
 @singleton
 class TempestConfig:
     """Provides OpenStack configuration information."""
 
     # TODO(yyekovenko) Temporary change of path to file
-    #DEFAULT_CONFIG_DIR = os.path.join(
+    # DEFAULT_CONFIG_DIR = os.path.join(
     #    os.path.abspath(os.path.dirname(os.path.dirname(__file__))),
     #    "etc")
 
@@ -687,9 +717,11 @@ class TempestConfig:
         register_opt_group(cfg.CONF, compute_admin_group, ComputeAdminGroup)
         register_opt_group(cfg.CONF, stress_group, StressGroup)
         register_opt_group(cfg.CONF, scenario_group, ScenarioGroup)
+        register_opt_group(cfg.CONF, cli_group, CLIGroup)
         register_opt_group(cfg.CONF, service_available_group,
                            ServiceAvailableGroup)
         register_opt_group(cfg.CONF, debug_group, DebugGroup)
+        register_opt_group(cfg.CONF, magnetodb_group, MagnetoDBGroup)
         self.compute = cfg.CONF.compute
         self.compute_feature_enabled = cfg.CONF['compute-feature-enabled']
         self.identity = cfg.CONF.identity
@@ -704,11 +736,13 @@ class TempestConfig:
         self.orchestration = cfg.CONF.orchestration
         self.dashboard = cfg.CONF.dashboard
         self.boto = cfg.CONF.boto
+        self.cli = cfg.CONF.cli
         self.compute_admin = cfg.CONF['compute-admin']
         self.stress = cfg.CONF.stress
         self.scenario = cfg.CONF.scenario
         self.service_available = cfg.CONF.service_available
         self.debug = cfg.CONF.debug
+        self.magnetodb = cfg.CONF.magnetodb
         if not self.compute_admin.username:
             self.compute_admin.username = self.identity.admin_username
             self.compute_admin.password = self.identity.admin_password
